#[ferritest]Expand description
#[ferritest] attribute macro.
Transforms an async function into a registered test case with automatic fixture injection based on parameter types.
#[ferritest]#[ferritest] attribute macro.
Transforms an async function into a registered test case with automatic fixture injection based on parameter types.