pub struct HookRegistration {
pub phase: HookPhase,
pub scope: HookScope,
pub owner: HookOwner,
pub tags: Option<String>,
pub requested_fixtures: Vec<String>,
}Expand description
Unified hook registration metadata used by adapters before execution hooks are built.
Fields
phase: HookPhasescope: HookScopeowner: HookOwnerrequested_fixtures: Vec<String>Trait Implementations
Sourceimpl Clone for HookRegistration
impl Clone for HookRegistration
Sourcefn clone(&self) -> HookRegistration
fn clone(&self) -> HookRegistration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookRegistration
impl Debug for HookRegistration
Sourceimpl PartialEq for HookRegistration
impl PartialEq for HookRegistration
Sourcefn eq(&self, other: &HookRegistration) -> bool
fn eq(&self, other: &HookRegistration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for HookRegistration
impl StructuralPartialEq for HookRegistration